aboutsummaryrefslogtreecommitdiff
path: root/bootstrap
diff options
context:
space:
mode:
Diffstat (limited to 'bootstrap')
-rw-r--r--bootstrap/Bootstrap.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/bootstrap/Bootstrap.php b/bootstrap/Bootstrap.php
index 05a3597..f6f1a54 100644
--- a/bootstrap/Bootstrap.php
+++ b/bootstrap/Bootstrap.php
@@ -15,5 +15,5 @@ $contact['database'] = new QueryBuilder(Connection::make($config['database']));
/* create new router */
$router = new Router;
-/* create new router */
-$navigator = new Navigator;
+/* create new navigation */
+$navigation = new Navigation;